projectm_touch_drag

Function projectm_touch_drag 

pub unsafe extern "C" fn projectm_touch_drag(
    instance: projectm_handle,
    x: f32,
    y: f32,
    pressure: c_int,
)
@brief Centers any waveforms under the coordinates to simulate dragging. @param instance The projectM instance handle. @param x The x coordinate of the drag. @param y the y coordinate of the drag. @param pressure The amount of pressure applied in a range from 0.0 to 1.0.