pub unsafe extern "C" fn projectm_write_debug_image_on_next_frame(
instance: projectm_handle,
output_file: *const c_char,
)Expand description
@brief Writes a .bmp main texture dump after rendering the next main texture, before shaders are applied.
If no file name is given, the image is written to the current working directory and will be named named “frame_texture_contents-YYYY-mm-dd-HH:MM:SS-frame.bmp”.
Note this is the main texture contents, not the final rendering result. If the active preset uses a composite shader, the dumped image will not have it applied. The main texture is what is passed over to the next frame, the composite shader is only applied to the display framebuffer after updating the main texture.
To capture the actual output, dump the contents of the main framebuffer after calling @a projectm_render_frame() on the application side.
@param instance The projectM instance handle. @param output_file The filename to write the dump to or NULL.